"use strict";
exports.__esModule = true;
exports.colorChineseString = void 0;
var getColorForTone_1 = require("./getColorForTone");
var hanRegex = /[\u4E00-\u9FCC\u3400-\u4DB5\uFA0E\uFA0F\uFA11\uFA13\uFA14\uFA1F\uFA21\uFA23\uFA24\uFA27-\uFA29]|[\ud840-\ud868][\udc00-\udfff]|\ud869[\udc00-\uded6\udf00-\udfff]|[\ud86a-\ud86c][\udc00-\udfff]|\ud86d[\udc00-\udf34\udf40-\udfff]|\ud86e[\udc00-\udc1d]/;
exports.colorChineseString = function (toneColors, chinese, pinyinStringSegments, defaultColor) {
    if (defaultColor === void 0) { defaultColor = 'black'; }
    var charIndex = 0;
    var segmentIndex = 0;
    var ret = [];
    while (charIndex < chinese.length) {
        if (hanRegex.test(chinese[charIndex])) {
            while (true) {
                if (segmentIndex >= pinyinStringSegments.length) {
                    // Chinese character and pinyin syllable counts do not match
                    return getColoringErrorResponse(chinese, defaultColor);
                }
                if (pinyinStringSegments[segmentIndex].type === 'PINYIN_SYLLABLE') {
                    break;
                }
                segmentIndex++;
            }
            var pinyinSyllable = pinyinStringSegments[segmentIndex];
            if (pinyinSyllable.erhua) {
                if (chinese[charIndex + 1] === '儿' || chinese[charIndex + 1] === '兒') {
                    ret.push({
                        chinese: chinese[charIndex],
                        color: getColorForTone_1.getColorForTone({
                            toneColors: toneColors,
                            tone: pinyinStringSegments[segmentIndex].tone
                        })
                    });
                    ret.push({
                        chinese: chinese[charIndex + 1],
                        color: toneColors.neutral
                    });
                    charIndex++;
                }
                else {
                    // Pinyin syllable carries erhua but the next char is not er
                    return getColoringErrorResponse(chinese, defaultColor);
                }
            }
            else {
                ret.push({
                    chinese: chinese[charIndex],
                    color: getColorForTone_1.getColorForTone({
                        toneColors: toneColors,
                        tone: pinyinStringSegments[segmentIndex].tone
                    })
                });
            }
        }
        else {
            ret.push({
                chinese: chinese[charIndex],
                color: defaultColor
            });
        }
        charIndex++;
        segmentIndex++;
    }
    while (segmentIndex < pinyinStringSegments.length) {
        if (pinyinStringSegments[segmentIndex].type === 'PINYIN_SYLLABLE') {
            // Chinese character and pinyin syllable counts do not match
            return getColoringErrorResponse(chinese, defaultColor);
        }
        segmentIndex++;
    }
    return ret;
};
var getColoringErrorResponse = function (chinese, defaultColor) {
    return chinese.split('').map(function (char) { return ({ chinese: char, color: defaultColor }); });
};
