"use strict";
exports.__esModule = true;
var _1 = require(".");
var toneColors = {
    first: '#3ce31a',
    second: '#41b4ff',
    third: '#ad634a',
    fourth: '#ff0000',
    neutral: '#6f6f6f'
};
describe('colorPinyinString', function () {
    it('handles simple pinyin', function () {
        var r = _1.colorPinyinString(toneColors, [
            {
                type: 'PINYIN_SYLLABLE',
                isCapitalized: true,
                initial: 'b',
                final: 'eng',
                tone: 2,
                erhua: false
            },
            {
                type: 'PINYIN_SYLLABLE',
                isCapitalized: false,
                initial: 'sh',
                final: 'uang',
                tone: 5,
                erhua: true
            },
        ]);
        expect(r).toMatchInlineSnapshot("\n      Array [\n        Object {\n          \"color\": \"#41b4ff\",\n          \"text\": \"B\u00E9ng\",\n        },\n        Object {\n          \"color\": \"#6f6f6f\",\n          \"text\": \"shuangr\",\n        },\n      ]\n    ");
    });
    it('handles text mixed with pinyin', function () {
        var r = _1.colorPinyinString(toneColors, [
            {
                type: 'TEXT',
                text: 'blabla jan'
            },
            {
                type: 'PINYIN_SYLLABLE',
                isCapitalized: false,
                initial: 'sh',
                final: 'uang',
                tone: 5,
                erhua: true
            },
        ]);
        expect(r).toMatchInlineSnapshot("\n      Array [\n        Object {\n          \"color\": \"black\",\n          \"text\": \"blabla jan\",\n        },\n        Object {\n          \"color\": \"#6f6f6f\",\n          \"text\": \"shuangr\",\n        },\n      ]\n    ");
    });
});
