"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
exports.__esModule = true;
exports.parsePinyinWithNumbers = void 0;
var pinyinTable_1 = require("./pinyinTable");
var INITIALS_BY_LENGTH = __spreadArrays(Object.keys(pinyinTable_1["default"])).sort(function (a, b) { return b.length - a.length; });
exports.parsePinyinWithNumbers = function (text) {
    var lowercaseText = text.toLocaleLowerCase();
    var i = 0;
    var currentNonPinyinText = '';
    var pinyinStringSegments = [];
    var state = 'DEFAULT';
    var matchedInitial = '';
    var matchedFinal = '';
    var flushCurrentNonPinyinText = function () {
        if (currentNonPinyinText.length > 0) {
            pinyinStringSegments.push({
                type: 'TEXT',
                text: currentNonPinyinText
            });
        }
    };
    while (i < text.length) {
        state_machine: switch (state) {
            case 'DEFAULT': {
                for (var _i = 0, INITIALS_BY_LENGTH_1 = INITIALS_BY_LENGTH; _i < INITIALS_BY_LENGTH_1.length; _i++) {
                    var initial = INITIALS_BY_LENGTH_1[_i];
                    if (lowercaseText.slice(i, i + initial.length) === initial) {
                        matchedInitial = initial;
                        state = 'INITIAL_MATCHED';
                        break state_machine;
                    }
                }
                currentNonPinyinText += text[i];
                i++;
                break state_machine;
            }
            case 'INITIAL_MATCHED': {
                var FINALS_BY_LENGTH = __spreadArrays(pinyinTable_1["default"][matchedInitial]).sort(function (a, b) { return b.length - a.length; });
                for (var _a = 0, FINALS_BY_LENGTH_1 = FINALS_BY_LENGTH; _a < FINALS_BY_LENGTH_1.length; _a++) {
                    var final = FINALS_BY_LENGTH_1[_a];
                    if (lowercaseText.slice(i + matchedInitial.length, i + matchedInitial.length + final.length) === final) {
                        matchedFinal = final;
                        state = 'FINAL_MATCHED';
                        break state_machine;
                    }
                }
                state = 'DEFAULT';
                currentNonPinyinText += text[i];
                i++;
                break state_machine;
            }
            case 'FINAL_MATCHED': {
                var nextCharacter = lowercaseText[i + matchedInitial.length + matchedFinal.length];
                if (['1', '2', '3', '4', '5'].includes(nextCharacter)) {
                    var pinyinSyllable = {
                        type: 'PINYIN_SYLLABLE',
                        isCapitalized: text[i] !== lowercaseText[i],
                        initial: matchedInitial,
                        final: matchedFinal,
                        tone: Number(nextCharacter),
                        erhua: false
                    };
                    flushCurrentNonPinyinText();
                    pinyinStringSegments.push(pinyinSyllable);
                    state = 'DEFAULT';
                    i += matchedInitial.length + matchedFinal.length + 1;
                    currentNonPinyinText = '';
                    break state_machine;
                }
                if (matchedInitial + matchedFinal === 'er') {
                    state = 'DEFAULT';
                    currentNonPinyinText += text[i];
                    i++;
                    break state_machine;
                }
                var charAfterNext = lowercaseText[i + matchedInitial.length + matchedFinal.length + 1];
                if (nextCharacter === 'r' && ['1', '2', '3', '4', '5'].includes(charAfterNext)) {
                    var pinyinSyllable = {
                        type: 'PINYIN_SYLLABLE',
                        isCapitalized: text[i] !== lowercaseText[i],
                        initial: matchedInitial,
                        final: matchedFinal,
                        tone: Number(charAfterNext),
                        erhua: true
                    };
                    flushCurrentNonPinyinText();
                    pinyinStringSegments.push(pinyinSyllable);
                    state = 'DEFAULT';
                    i += matchedInitial.length + matchedFinal.length + 2;
                    currentNonPinyinText = '';
                    break state_machine;
                }
                state = 'DEFAULT';
                currentNonPinyinText += text[i];
                i++;
                break state_machine;
            }
        }
    }
    flushCurrentNonPinyinText();
    return pinyinStringSegments;
};
